## Alpaca
![alpaca_logo](examples/figures/alpaca.png)

Package for active learning and uncertainty quantification in neural nets.

## Installation

You can install the package via pip
```
pip install alpaca-ml
```

## Code examples
Tutorial are available as example notebooks in `examples` folder.

- [Uncertainty for classification task](examples/classification_uq.ipynb)
- [Uncertainty for regression task](examples/regression_uq.ipynb)
- [Active learning on regression](examples/active_learning.ipynb)
- [Uncertainty visualization](examples/visualization.ipynb)
